
# Overview
Super simple app for manually testing connections to a websocket server.

# Install
```bash
pip install wscat
```

# Example
```bash
# Connect to a server on port 8080
wscat ws://some.server.here:8080

# Send whatever
```